/*
 * jSite-next - ListenerSupport.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.util.event;

import java.util.EventListener;

/**
 * Helper class to manager {@link EventListener}s and a fixed source for events.
 *
 * @param <S>
 *            The type of the source
 * @param <L>
 *            The type of the listeners
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public class FixedSourceListenerSupport<S, L extends EventListener> extends ListenerSupport<L> {

	/** The source of the events. */
	private final S source;

	/**
	 * Creates a new listener support.
	 *
	 * @param source
	 *            The source of all events
	 */
	public FixedSourceListenerSupport(S source) {
		this.source = source;
	}

	/**
	 * Returns the source of all events.
	 *
	 * @return The source of all events
	 */
	protected S getSource() {
		return source;
	}

}
